const { createContext, useContext, Component } = React;
const NotificationContext = createContext();



class NotificationProvider extends Component {
  constructor(props) {
    super(props);
    this.state = {
      notifications: [],
    };
  }

  addNotification = (message, type) => {
    this.setState((prevState) => ({
      notifications: [...prevState.notifications, { message, type }],
    }));

    setTimeout(() => {
      this.setState((prevState) => ({
        notifications: prevState.notifications.slice(1),
      }));
    }, 10000);
  };

  render() {
    return (
      <NotificationContext.Provider value={{ addNotification: this.addNotification }}>
        {this.props.children}
        <div className="notification-container">
          {this.state.notifications.map((notif, index) => (
            <div key={index} className={`notification ${notif.type}`}>
              {notif.message}
            </div>
          ))}
        </div>
      </NotificationContext.Provider>
    );
  }
}

const useNotification = () => useContext(NotificationContext);

class ReservationSystem extends Component {
  static contextType = NotificationContext;

  constructor(props) {
    super(props);
    this.state = {
      entryType: 'single',
      selectedOption: null,
      consultation: false,
      consultationType: null,
      totalPrice: 0,
      selectedDates: [],
      selectedTime: null,
      maxDates: 1,
      loading:true,
      pay:true,
      userData:null,
      userDetails: { name: '', email: '', phone: '' },
      unavaibleDates:[],
      calendarInstance: null,
    };
    
    this.texts={
        entryType:{
          single:"Jednorázový vstup",
          permanent:"Permanentka"
        }
    };
    this.interval = null
  }

  componentDidMount() {
    this.getData();
  }

  componentDidUpdate(prevProps, prevState) {
    if (prevState.maxDates !== this.state.maxDates) {
      this.initializeCalendar();
    }
    if (prevState?.userDetails?.email !== this.state?.userDetails?.email)
    {
      this.getUserData();
    }
  }

  getUserData() {
    let $orderId = JSON.parse(localStorage.getItem("reserve")??"{}");
    
    fetch('https://easylight.perity.net/backend/get.php', {
      method: 'POST',
      headers: {'Accept': 'application/json','Content-Type': 'application/json'},
      body: JSON.stringify({
          what:"reserve",
          where:"date >= NOW() AND (status IS NULL OR status != 'DELETED') AND order_id="+($orderId?.data?.order_id??0)+" OR email='"+shopDataLayerData.customer?.email+"'",
          multiple:false,
      }),
    }).then((e)=>e.json())
      .then((response) => {
        if(response?.reserve)
        {
          this.setState({
            userData:response?.reserve[0],
            loading:false
          },()=>{
            clearInterval(this.interval);
            this.interval = null;
          })
        }
      })
  }

  getData() {
    fetch('https://easylight.perity.net/backend/get.php', {
      method: 'POST',
      headers: {'Accept': 'application/json','Content-Type': 'application/json'},
      body: JSON.stringify({
          what:"reservations,reserve",
          select:["*","date"],
          where:["","date >= NOW() AND COALESCE(status, '') != 'DELETED'"],
          multiple:true,
      }),
    }).then((e)=>e.json())
      .then((response) => {
      if (response) {
        let acc = {}, 
        unavaibleDates = this.formatDateArray(response['reserve']);
        response["reservations"].map((item, key) => {
          let c = item.category;
          acc[c] = acc[c]?[...acc[c], item]:[item];
          return item;
        }, {});
        
        this.setState({ reservationData: acc, unavaibleDates, loading: false },()=>{
          this.getUnavaibleDates();
          this.getUserData();
          this.initializeCalendar();
        });
      }
    });
  }

  getUnavaibleDates()
  {
    if(!this.interval)
    {
      this.interval = setInterval(()=>{
        this.getUnavaibleDates()
      },10000);
    }
    fetch('https://easylight.perity.net/backend/get.php', {
      method: 'POST',
      headers: {'Accept': 'application/json','Content-Type': 'application/json'},
      body: JSON.stringify({
          what:"reserve",
          select:"date,dates",
          where:"status IS NULL OR status != 'DELETED'",
          multiple:false,
      }),
    }).then((e)=>e.json())
      .then((r) => {
        if(r)
        {
            let newArray = [];
            r?.map(r=>{
                const {date,dates} = r
                if(typeof dates === "string")
                {
                    let d = JSON.parse(dates)
                    d.map((e)=>{
                        if(this.isActiveDate(e?.fullDate))
                        {
                            newArray.push({date:this.formatDate(e.fullDate)})
                        }
                    })
                }
                if(date && this.isActiveDate(date))
                {
                    newArray.push({date:this.formatDate(date)})
                }
            })

            let unavaibleDates = this.formatDateArray(newArray);
            this.setState({ unavaibleDates })
        }
      });

  }
  isActiveDate(date) {
    return new Date(date) >= new Date();
  }
  formatDate(e)
  {
      let date = new Date(e),
      hours = String(date.getHours()).padStart(2, '0'),
      minutes = String(date.getMinutes()).padStart(2, '0');
      return date.getFullYear()+"-"+(date.getMonth()+1)+"-"+date.getDate()+" "+hours+":"+minutes
  }
  formatDateArray(inputArray) {
    const result = {};

    if(!Array.isArray(inputArray))
    {
        return Object.values(result);
    }
    
    inputArray?.forEach(item => {
        const [datePart, timePart] = item?.date?.split(" ");
        const formattedTime = timePart.substring(0, 5); // Odstránenie sekúnd
        
        if (!result[datePart]) {
            result[datePart] = { date: datePart, times: [] };
        }
        
        result[datePart].times.push(formattedTime);
    });

    return Object.values(result);
  }
  initializeCalendar = () => {
    const {calendarInstance,unavaibleDates,entryType,maxDates} = this.state
    if (calendarInstance && typeof calendarInstance?.destroy === "function") {
      calendarInstance?.destroy();
    }
    
    const calendar = flatpickr("#inline-calendar", {
      dateFormat: "Y-m-d", // Format date and time together
      minDate: new Date().toISOString().split('T')[0],
      maxDate: new Date().fp_incr(365),
      enableTime: false,
      mode: "single",//entryType == "permanent" ? "multiple" : "single",
      disable: this.getDisabledDates(),
      locale: {
        firstDayOfWeek: 1,
        weekdays: {
          shorthand: ['Ne', 'Po', 'Ut', 'St', 'Št', 'Pi', 'So'],
          longhand: ['Nedeľa', 'Pondelok', 'Utorok', 'Streda', 'Štvrtok', 'Piatok', 'Sobota']
        },
        months: {
          shorthand: ['Jan', 'Feb', 'Mar', 'Apr', 'Máj', 'Jún', 'Júl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec'],
          longhand: ['Január', 'Február', 'Marec', 'Apríl', 'Máj', 'Jún', 'Júl', 'August', 'September', 'Október', 'November', 'December']
        }
      },
      inline: true,
      onChange: (selectedDates) => {

        if (selectedDates.length > maxDates) {
          while (selectedDates.length > maxDates) {
            selectedDates.pop();
          }
        }
        
        this.setState({ selectedDates, selectedTime: null }, this.calculatePrice);
        calendar.setDate(selectedDates);
      },
    });

    this.setState({ calendarInstance:calendar });
  };

  calculatePrice = () => {
    let price = 0;
    const { entryType, selectedOption, consultation, consultationType,reservationData } = this.state,
          {consultations} = reservationData;
      const selected = reservationData[entryType]?.find(e=>e.id === selectedOption ),
            consultationSelected = consultations?.find(e=>e.id === consultationType);

    price += parseInt(selected?.price??0);

    if (consultation && (consultationType != undefined || consultationType != null)) {
      price +=  parseInt(consultationSelected?.price)??0;
    }

    this.setState({ totalPrice: price });
  };

  getAvailableTimes = () => {
    const {reservationData} = this.state;
    return reservationData?.generalTimes?.map((e)=>this.formatTime(e?.time));
  };
  formatTime = (time) => {
    return time.slice(0, 5);
  };
  
  isTimeUnavailable = (time, unavaibleDates) => {
    const { selectedDates, selectedTime } = this.state;
    if (selectedDates.length === 0) {
      return true; // Ak nie je vybraný dátum, všetky časy sú zakázané
    }
  
    const selectedDate = selectedDates[0],
          currentDate = new Date();
          currentDate.setHours(currentDate.getHours()+1) // Set time to +1 hour
  
    // Ak je aktuálny dátum zvolený, kontrolujeme aktuálny čas
    if (
      currentDate.getFullYear() === selectedDate.getFullYear() &&
      currentDate.getMonth() === selectedDate.getMonth() &&
      currentDate.getDate() === selectedDate.getDate()
    ) {
      const [hour, minutes] = time.split(":").map(Number),
            sTime = new Date();
      sTime.setHours(hour, minutes, 0, 0);

      if (sTime <= currentDate) {
        return true;
      }
  
    }
  
    // Nájdeme záznam pre aktuálny dátum
    const unavailableForDate = unavaibleDates.find((entry) => {
      const entryDate = new Date(entry.date);
      return (
        entryDate.getFullYear() === selectedDate.getFullYear() &&
        entryDate.getMonth() === selectedDate.getMonth() &&
        entryDate.getDate() === selectedDate.getDate()
      ); // Porovnáme rok, mesiac a deň
    });

    if(unavailableForDate ? unavailableForDate.times.includes(selectedTime):false)
    {
      this.setState({
        selectedTime:null
      })
    }
  
    // Ak existuje záznam, kontrolujeme, či čas patrí medzi nedostupné
    return unavailableForDate ? unavailableForDate.times.includes(time) : false;
  };
  
getDisabledDates() {
  const availableTimes = this.getAvailableTimes(),
        {unavaibleDates} = this.state;
  let blockedDates = [];
  
  unavaibleDates?.forEach(dateObj => {
        if (availableTimes?.every(time => dateObj?.times.includes(time))) {
            blockedDates.push(dateObj.date);
        }
    });
    // Pridanie víkendov (soboty a nedele) do blokovaných dátumov
    const currentDate = new Date();
    const oneYearFromNow = new Date();
    oneYearFromNow.setFullYear(currentDate.getFullYear() + 1);

    for (let d = new Date(currentDate); d <= oneYearFromNow; d.setDate(d.getDate() + 1)) {
        if (d.getDay() === 0 || d.getDay() === 6) { // 0 = nedeľa, 6 = sobota
            blockedDates.push(d.toISOString().split('T')[0]);
        }
    }

    return blockedDates;
}
  // Nastaví vybraný čas
  handleTimeSelection = (time) => {
    this.setState({ selectedTime: time });
  };

  handleEntryTypeChange = (entryType) => {
    const {calendarInstance} = this.state
    if(calendarInstance && typeof calendarInstance.setDate === "function")
    {
      calendarInstance.setDate(null)
    }
    this.setState({ entryType, selectedOption: null , maxDates: 1 }, this.calculatePrice);
  };

  handleOptionChange = (option) => {
    const {selectedDates,calendarInstance,reservationData} = this.state,
          maxDates = 1
    // Handle permanent days count change, deselect all dates more then permanent
    if (selectedDates.length > maxDates) {
      while (selectedDates.length > maxDates) {
        selectedDates.pop();
      }
    }
    calendarInstance?.setDate(selectedDates)

    this.setState(
      { selectedOption: option, maxDates, selectedDates,
        selectedTime: null},
      this.calculatePrice
    );
  };

  handleUserDetailsChange = (e) => {
    const { name, value } = e.target;
    this.setState((prevState) => ({
      userDetails: { ...prevState.userDetails, [name]: value },
    }));
  };

  validateForm = () => {
    const { userDetails, selectedOption, entryType, selectedDates, maxDates, selectedTime, consultationType, consultation } = this.state;
    if (!userDetails.name || !userDetails.email || !userDetails.phone) {
      return 'Prosím, vyplňte všetky údaje.'
    }
    if (!selectedOption) {
      return 'Prosím, vyberte jednu z možností.';
    }
    if(consultation && (consultationType === undefined || consultationType === null))
    {
      return 'Prosím zvolte si typ konzultácie.'
    }
    /*
    if (entryType === 'permanent' && (selectedDates.length < 1 || selectedDates.length !== maxDates)) { 
      return "Vyberte všetky dátumi a časy pre permanentku."
    }
    */
    if(selectedDates.length < 1 || (selectedTime === null || selectedTime === undefined))
    {
      return "Prosím zvolte si dátum a čas."
    }
    return true;
  };
  
  handleSubmit(e){
    e.preventDefault();
    this.setState({loading:true});

    const validator = this.validateForm();
    if (validator !== true) {
      this.context.addNotification(validator, 'error');
      this.setState({loading:false});
      return;
    }
    
    const {userDetails,entryType,selectedOption,selectedDates,consultation,consultationType,totalPrice,selectedTime,pay} = this.state,
          {name,email,phone} = userDetails,
          [hour, minutes] = selectedTime.split(":").map(Number)
    selectedDates[0].setHours(hour - (selectedDates[0].getTimezoneOffset() / 60), minutes, 0, 0);

    const data = {
            name,
            email,
            phone,
            type: entryType,
            option:selectedOption,
            date:selectedDates[0],
            consultation,
            pay,
            consultationType,
            price:totalPrice.toFixed(2),
            key:"1765654728891",
            url:window.location.href
    };

    this.createPayment(data);

  }
  createPayment(data)
  {
    if(PerityNet.goPayUrl != null && PerityNet.paymentId != null && PerityNet.form === JSON.stringify(data))
    {
        _gopay.checkout({gatewayUrl: PerityNet.goPayUrl, inline: true}, ()=>getStatus(PerityNet.paymentId,data,"reserve"));
        return;
    }
    const {calendarInstance} = this.state
    fetch('https://easylight.perity.net/backend/create-payment-reserve.php', {
      method: 'POST',
      headers: {'Accept': 'application/json','Content-Type': 'application/json'},
      body: JSON.stringify(data),
    }).then((e)=>e.json())
    .then((result)=>{
      
      PerityNet.paymentId = result.id;
      PerityNet.goPayUrl = result.gw_url;
      PerityNet.form = JSON.stringify(data);
      let saveData = {
        payment_id: result.id,
        order_id: result.order_number ?? result.order_id
      }
      localStorage.setItem("reserve",JSON.stringify({data:saveData}));

      this.setState({
        userDetails: { name: '', email: '', phone: '' },
        selectedOption: null,
        consultation: false,
        consultationType: '',
        selectedDates: [],
        totalPrice: 0
      },()=>{
        if(calendarInstance && typeof calendarInstance.setDate === "function")
        {
          calendarInstance?.setDate(null);
        }
        this.getData();
      })

      if(result?.upload)
      {
        this.context.addNotification('Rezervácia bola úspešne odoslaná!', 'success');
        return;
      }

        // We don't need to extract the ID from the argument object
        _gopay.checkout({gatewayUrl: result.gw_url, inline: true}, ()=>{getStatus(result.id, data, "reserve");this.getUserData()});
        
    }).catch((e)=>{
      this.context.addNotification('Došlo k chybe pri odosielaní rezervácie!', 'error');
    })
  }
  rePay(e)
  {
    const {userData} = this.state
    this.setState({loading:true});

    const data = {
      ...userData,
      pay:true,
      key:"1765654728891",
      url:window.location.href
    };
    if(!e)
    {
      this.createPayment(data);
    }
    else
    {
      fetch(Server+"/backend/status.php", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
          Accept: "application/json"
        },
        body: JSON.stringify({id:e,type:"reserve"})
      }).then((e)=>e.json())
      .then((result)=>{
          PerityNet.paymentId = result.id;
          PerityNet.goPayUrl = result.gw_url;
          PerityNet.form = JSON.stringify(userData);
          let saveData = {
            payment_id: result.id,
            order_id: result.order_number ?? result.order_id
          }
          localStorage.setItem("reserve",JSON.stringify({data:saveData}));
          // We don't need to extract the ID from the argument object
          _gopay.checkout({gatewayUrl: result.gw_url, inline: true}, ()=>{getStatus(result.id, userData, "reserve");this.getUserData()});

      }).catch((e)=>{
        this.context.addNotification('Došlo k chybe pri odosielaní rezervácie!', 'error');
      });

    }

  }
  cancelReservation(e)
  {
    const {userData} = this.state,
    data = {
      id:userData.id,
      order_id: userData.order_id,
      payment_id:userData.payment_id,
      email:userData.email,
      key:"1765654728891",
      url:window.location.href
    };
    this.setState({loading:true});

    fetch(Server+"/backend/cancel.php", {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
        Accept: "application/json"
      },
      body: JSON.stringify(data)
    }).then((e)=>e.json())
    .then((result)=>{
      if(result?.upload)
      {

        PerityNet.paymentId = null;
        PerityNet.goPayUrl = null;
        PerityNet.form = null;
        localStorage.removeItem("reserve");
        this.setState({
          userData:null,
          userDetails: { name: '', email: '', phone: '' },
          selectedOption: null,
          selectedTime: null,
          entryType: null,
          calendarInstance:null,
          consultation: false,
          consultationType: '',
          selectedDates: [],
          totalPrice: 0
        },()=>{
          this.getUserData();
          this.getData();
          this.context.addNotification('Vaša rezervácia bola vymazaná!', 'success');
        })
        
      }

    }).catch((e)=>{
      this.context.addNotification('Došlo k chybe pri vymazávaní rezervácie!', 'error');
      this.setState({loading:false});
    });
  }

  getDate(e)
  {
      let date = new Date(e),
      hours = String(date.getHours()).padStart(2, '0'),
      minutes = String(date.getMinutes()).padStart(2, '0');
      return date.getDate()+"."+(date.getMonth()+1)+"."+date.getFullYear()+" | "+hours+":"+minutes
  }
  getText(p)
  {
    const {reservationData} = this.state
    return reservationData?.texts?.filter((e)=> e.usedFor === p)[0]?.label
  }

  render() {
    const {
      entryType,
      selectedOption,
      consultation,
      pay,
      consultationType,
      totalPrice,
      userDetails,
      reservationData,
      calendarInstance,
      unavaibleDates,
      loading,
      userData
    } = this.state
    let selected = {}

    if(reservationData)
    {
      selected = {
        consultation: reservationData?.consultations?.find(e=>e.id === consultationType),
        entry: reservationData[entryType]?.find(e=>e.id === selectedOption)
      }
    }
    if(userData && reservationData)
    {
      selected = {
        consultation: reservationData?.consultations?.find(e=>parseInt(e.id) === parseInt(userData["consultationType"])),
        entry: reservationData[userData["type"]]?.find(e=>parseInt(e.id) === parseInt(userData["option"]))
      }
      if(calendarInstance && typeof calendarInstance.destroy === "function")
      {
        calendarInstance?.destroy();
      }
      
      return(
        <div className={"contaier"+(loading?" loading":"")}>

          <div className="separate">
            <h3>Vaša rezervácia</h3>
            <p><b>Dátum:</b> {this.getDate(userData["date"])}</p>
            {
              selected?.consultation && (
                <>
                  <p><b>Konzultácia:</b> {selected.consultation?.label}</p>
                  <p>{selected.consultation?.description}</p>
                </>
              )
            }
                          <div className="order-summary">
                <div className="order-summary-top">
                  <h4>Zhrnutie rezervácie</h4>
                  <div id="shipping-billing-summary" className="order-recapitulation">

                    
                      <div className="recapitulation-single">
                        <strong>
                            {reservationData &&(
                              <>
                              <span> {selected?.entry?.price??0}€ </span> {this.getText(userData["type"])} - {selected?.entry?.label??""}
                              </>
                            )}
                        </strong>
                      </div>
                    {selected?.consultation && (
                      <div className="recapitulation-single">
                        <strong>
                          <span> {selected?.consultation?.price??0}€ </span>
                          Konzultácia - {selected?.consultation?.label}
                        </strong>
                      </div>
                    )}

                    <div className="order-summary-item price">
                      <div className="price-wrapper">
                        <h5 className="price-label price-primary">Celková suma </h5>
                        <strong className="price price-primary price-primary-full">
                          <span data-testid="recapFullPriceMonth">{userData["price"]}€</span>
                        </strong>
                      </div>
                    </div>


                </div>
            </div>
            </div>
            <div className="order-summary-item price">
              <div className="price-wrapper">
                <h5 className="price-label price-primary">Stav
                </h5>
                <strong className="price price-primary price-primary-full">
                  <span data-testid="recapFullPriceMonth">{userData["status"] === "PAID"?"Zaplatené":"Nezaplatené"}</span>
                </strong>
              </div>
            </div>
            <br/>
            <div className="boxButtons">
            {
              userData["status"] != "PAID" && (
                <>
                  <button type="submit" className="btn btn-secondary btn-cart" onClick={()=>{this.rePay(userData['payment_id'])}}>Zaplatiť rezerváciu</button>
                  <button type="submit" className="btn btn-primary btn-text" onClick={()=>{this.cancelReservation(userData['payment_id'])}}>Zrušiť rezerváciu</button>
                </>
              )
            }
            </div>
          </div>
        </div>

      )
    }

    return (
      <div className={"contaier"+(loading?" loading":"")}>
        <form id="reserveForm" onSubmit={(e)=>this.handleSubmit(e)}>
          <div className="separate">

          <div className="form-group">
            <label>Typ vstupu:</label>
            <div className="form-check">
              <input
                type="checkbox"
                id="single"
                checked={entryType === 'single'}
                onChange={() => this.handleEntryTypeChange('single')}
              />
              <label
                className={`btn ${entryType === 'single' ? 'btn-selected' : ''}`}
                htmlFor="single"
              >
                {this.getText("single")}
              </label>
            </div>

            <div className="form-check">
              <input
                type="checkbox"
                id="permanent"
                checked={entryType === 'permanent'}
                onChange={() => this.handleEntryTypeChange('permanent')}
              />
              <label
                className={`btn ${entryType === 'permanent' ? 'btn-selected' : ''}`}
                htmlFor="permanent"
              >
                {this.getText("permanent")}
              </label>
            </div>
          </div>

          {entryType === 'single' && (
            <div className="form-group">
              <label>{this.getText("single")}:</label>
              {reservationData?.single?.map(({ label, price, id },key) => (
                <div key={id+'-'+key} className="form-check">
                  <input
                    type="checkbox"
                    id={id+'-'+key}
                    checked={selectedOption === id}
                    onChange={() => this.handleOptionChange(id)}
                  />
                  <label
                    className={`btn ${selectedOption === id ? 'btn-selected' : ''}`}
                    htmlFor={id+'-'+key}
                  >
                    {label} - {price}€
                  </label>
                </div>
              ))}
            </div>
          )}

          {entryType === 'permanent' && (
            <div className="form-group">
              <label>{this.getText("permanent")}:</label>
              {reservationData?.permanent?.map(({ label, price, id },key) => (
                <div key={id+'-'+key} className="form-check">
                  <input
                    type="checkbox"
                    id={id+'-'+key}
                    checked={selectedOption === id}
                    onChange={() => this.handleOptionChange(id)}
                  />
                  <label
                    className={`btn ${selectedOption === id ? 'btn-selected' : ''}`}
                    htmlFor={id+'-'+key}
                  >
                    {label} - {price}€
                  </label>
                </div>
              ))}
            </div>
          )}

          <div className="calendar-container">
            <div id="inline-calendar"></div>

            <div className="form-group times-container">
              <label className="form-label">Vyberte čas:</label>
              <div className="time-buttons">
                {this.getAvailableTimes()?.map((time, index) => {
                  const isUnavailable = this.isTimeUnavailable(time,unavaibleDates);
                  return (
                    <button
                      key={index}
                      type="button"
                      className={`btn ${
                        this.state.selectedTime === time
                          ? "btn-primary"
                          : isUnavailable
                          ? "btn-disabled"
                          : "btn-outline-primary"
                      }`}
                      onClick={() => !isUnavailable && this.handleTimeSelection(time)}
                      disabled={isUnavailable}
                    >
                      {time}
                    </button>
                  );
                })}
              </div>
            </div>
          </div>

          <div className="form-group">
            <label>Chcete konzultáciu? (30 minút)</label>
            <div className="form-check">
              <input
                type="checkbox"
                id="consultation"
                checked={consultation}
                onChange={(e) => this.setState({ consultation: e.target.checked }, this.calculatePrice)}
              />
              <label
                className={`btn ${consultation ? 'btn-selected' : ''}`}
                htmlFor="consultation"
              >
                Áno
              </label>
            </div>
          </div>

          {consultation && (
            <div className="form-group">
              <label>Typ konzultácie:</label>
              {reservationData?.consultations?.map(({ label, price, id,description },key) => (
                <div key={id+'-'+key} className="form-check">
                  <input
                    type="checkbox"
                    id={id+'-'+key}
                    checked={consultationType === id}
                    onChange={() => this.setState({ consultationType: id }, this.calculatePrice)}
                  />
                  <label
                    className={`btn ${consultationType === id ? 'btn-selected' : ''}`}
                    htmlFor={id+'-'+key}
                  >
                    {label} - {price}€
                    <div className="tooltip"><span>{description}</span></div>
                  </label>
                </div>
              ))}
            </div>
          )}


          </div>
          <div className="separate right">
            <div className="box co-box co-contact-information">
              <h4>Osobné údaje</h4>
              <div className="form-group">
                <label for="name" className="required-asterisk">Meno a priezvisko</label>
                <input
                  type="text"
                  className="form-control"
                  name="name"
                  value={userDetails.name}
                  onChange={this.handleUserDetailsChange}
                />
              </div>

              <div className="form-group">
                <label for="email" className="required-asterisk">Email:</label>
                <input
                  type="email"
                  className="form-control"
                  name="email"
                  value={userDetails.email}
                  onChange={this.handleUserDetailsChange}
                />
              </div>

              <div className="form-group">
                <label for="phone" className="required-asterisk">Telefón:</label>
                <input
                  type="tel"
                  className="form-control"
                  name="phone"
                  value={userDetails.phone}
                  onChange={this.handleUserDetailsChange}
                />
              </div>
              
              <div className="form-group button-slider">
                <label>Platba online:</label>
                <div className="form-check">
                  <input
                    type="checkbox"
                    id="pay"
                    checked={pay}
                    onChange={(e) => this.setState({ pay: e.target.checked })}
                  />
                  <label
                    className={`btn btn-slider ${pay ? 'btn-selected' : ''}`}
                    htmlFor="pay"
                  >
                  </label>
                </div>
              </div>
            </div>

              <div className="order-summary">
                <div className="order-summary-top">
                  <h4>Zhrnutie rezervácie</h4>
                  <div id="shipping-billing-summary" className="order-recapitulation">

                    
                      <div className="recapitulation-single">
                        <strong>
                            {reservationData &&(
                              <>
                              <span> {selected?.entry?.price??0}€ </span> {this.getText(entryType)} - {selected?.entry?.label??""}
                              </>
                            )}
                        </strong>
                      </div>
                    {consultation && consultationType !== null && (
                      <div className="recapitulation-single">
                        <strong>
                          <span> {selected?.consultation?.price??0}€ </span>
                          Konzultácia - {selected?.consultation?.label}
                        </strong>
                      </div>
                    )}
                    
                    <div className="order-summary-item price">
                      <div className="price-wrapper">
                        <h5 className="price-label price-primary">Celková suma </h5>
                        <strong className="price price-primary price-primary-full">
                          <span data-testid="recapFullPriceMonth">{totalPrice??0}€</span>
                        </strong>
                      </div>
            
                    </div>
                </div>
            </div>
            </div>
          <button type="submit" className="btn btn-secondary btn-text">Odoslať{pay&&(" a zaplatiť")} rezerváciu</button>
           
          </div>
        </form>
        <div className="loading"></div>
      </div>
    );
  }
}
const root = ReactDOM.createRoot(document.getElementById('reservationReactRoot'));

root.render(
  <NotificationProvider>
    <ReservationSystem />
  </NotificationProvider>
);